Current List of itwinai Plugins
===============================

Below is a list of existing **itwinai plugins**, which correspond to scientific use cases that have been integrated into the itwinai framework.

Physics Sciences
----------------

- `3DGAN – Fast Simulation of Particles in Calorimeters <https://github.com/interTwin-eu/itwinai-3dgan-plugin>`__
- `GlitchFlow – Noise Generation for Gravitational Waves Analysis at Virgo <https://github.com/interTwin-eu/glitchflow-itwinai-plugin>`__
- `Pulsar Detection (Radio Astronomy) <https://github.com/interTwin-eu/pulsar-plugin>`__
- `Machine Learned Particle Flow Reconstruction (MLPF) <https://github.com/matbun/mlpf-itwinai-plugin>`__
- `Normflow - Normalizing flows as a generative model for lattice field theory <https://github.com/interTwin-eu/normflow-plugin>`__

Environmental Sciences
-----------------------

- `Hython – Hydrological Modelling for Drought Early Warnings <https://github.com/interTwin-eu/hython-itwinai-plugin>`__
- `xtclim – ML-based extreme events detection and characterization (CERFACS) <https://github.com/interTwin-eu/xtclim>`__
- `AtmoRep – A Stochastic Model of Atmosphere Dynamics <https://github.com/matbun/atmorep-itwinai-plugin>`__

Contribute Your Plugin
-----------------------

If you are developing a plugin and would like it to be listed on this page, feel free to open a pull request to update it!
